// (C) 2007-2025 GoodData Corporation
import { isAbsoluteDateFilterOptionChangedDetails, } from "../interfaces/index.js";
import { isAbsoluteDateFilterForm, isRelativeDateFilterForm } from "@gooddata/sdk-model";
import { convertPlatformDateStringToDate } from "../utils/DateConversions.js";
import { messages } from "../../locales.js";
const validateVisibility = (filterOption) => {
    const errors = {};
    if (!filterOption.visible) {
        // indicate that the Apply button should be disabled, it makes no sense for hidden forms
        errors[filterOption.type] = {};
    }
    return errors;
};
const isSameDay = (d1, d2) => {
    return (!!d1 &&
        !!d2 &&
        d1.getFullYear() === d2.getFullYear() &&
        d1.getMonth() === d2.getMonth() &&
        d1.getDate() === d2.getDate());
};
const setError = (errors, field, errorType, errorId) => {
    return {
        ...errors,
        absoluteForm: {
            ...(errors.absoluteForm ?? {}),
            [field]: {
                ...(errors.absoluteForm?.[field] ?? {}),
                [errorType]: errorId,
            },
        },
    };
};
const setDateError = (errors, field, errorId) => setError(errors, field, "dateError", errorId);
const setTimeError = (errors, field, errorId) => setError(errors, field, "timeError", errorId);
const validateStartAfterEnd = (errors, filterOption, changeDetails) => {
    const start = convertPlatformDateStringToDate(filterOption.from);
    const end = convertPlatformDateStringToDate(filterOption.to);
    if (start > end) {
        if (changeDetails?.rangePosition === "from") {
            if (isSameDay(start, end)) {
                return setTimeError(errors, "from", messages.errorStartTimeAfterEndTime.id);
            }
            return setDateError(errors, "from", messages.errorStartDateAfterEndDate.id);
        }
        else {
            if (isSameDay(start, end)) {
                return setTimeError(errors, "to", messages.errorEndTimeBeforeStartTime.id);
            }
            return setDateError(errors, "to", messages.errorEndDateBeforeStartDate.id);
        }
    }
    return errors;
};
const validateAbsoluteForm = (filterOption, changeDetails) => {
    const parseError = changeDetails?.parseError;
    let errors = validateVisibility(filterOption);
    if (filterOption.from === undefined) {
        // the logic prioritizes "invalid" because "empty" is considered default when no details are provided
        errors = setDateError(errors, "from", parseError === "invalid" ? messages.errorInvalidStartDate.id : messages.errorEmptyStartDate.id);
    }
    if (filterOption.to === undefined) {
        errors = setDateError(errors, "to", parseError === "invalid" ? messages.errorInvalidEndDate.id : messages.errorEmptyEndDate.id);
    }
    // both dates are correct, lets proceed to checks that requires both dates
    if (errors.absoluteForm === undefined) {
        errors = validateStartAfterEnd(errors, filterOption, changeDetails);
    }
    return errors.absoluteForm === undefined ? {} : errors;
};
const validateRelativeForm = (filterOption) => {
    const errors = validateVisibility(filterOption);
    const relativeFormKeys = ["from", "to"];
    relativeFormKeys.forEach((field) => {
        if (filterOption[field] === undefined) {
            errors.relativeForm = errors.relativeForm || {};
            // There is no validation message as we have no place to show it
        }
    });
    return errors.relativeForm ? errors : {};
};
export const validateFilterOption = (filterOption, changeDetails) => {
    if (isAbsoluteDateFilterForm(filterOption)) {
        return validateAbsoluteForm(filterOption, isAbsoluteDateFilterOptionChangedDetails(changeDetails) ? changeDetails : undefined);
    }
    else if (isRelativeDateFilterForm(filterOption)) {
        return validateRelativeForm(filterOption);
    }
    else {
        return validateVisibility(filterOption);
    }
};
//# sourceMappingURL=OptionValidation.js.map